#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-middleware-static
version:              0.9.4
visibility:           public
id:                   wai-middleware-static-0.9.4-D931pgEuqYG9ZDFFZVDOwy
key:                  wai-middleware-static-0.9.4-D931pgEuqYG9ZDFFZVDOwy
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  aac80f63bfa1ad378144596b71138a5a
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-middleware-static-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.4-D931pgEuqYG9ZDFFZVDOwy
depends:
    base-4.18.2.1 base16-bytestring-1.0.2.0-HKNPUjeO8LQ9RSeGAokMwf
    bytestring-0.11.5.3
    cryptohash-sha1-0.11.101.0-EYRlHYNpqN36EzjsucJ4qd directory-1.3.8.5
    expiring-cache-map-0.0.6.1-2MnjofvI6K9FJeTYil0YkD
    filepath-1.4.300.1 http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN text-2.0.2 time-1.12.2
    wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

